#ifndef config_h
#define config_h

#define ABOOT_MAJOR	0
#define ABOOT_MINOR	7
#define ABOOT_MAGIC	0x30302d746f6f6261 /* "aboot-00" */

#define CONFIG_FILE_PARTITION	1
#define CONFIG_FILE		"/etc/aboot.conf"

#endif /* config_h */
